@@ -702,7 +702,7 @@ int main(int argc, char **argv)
 	igt_fixture {
 		drm_fd = drm_open_any();
 		if (!dry_run)
-			do_or_die(igt_set_vt_graphics_mode());
+			igt_set_vt_graphics_mode();
 
 		drm_resources = drmModeGetResources(drm_fd);
 		assert(drm_resources);
